@@ -40,7 +40,6 @@ from hypothesis._settings import (
     Phase,
     Verbosity,
     local_settings,
-    note_deprecation,
     settings as Settings,
 )
 from hypothesis.control import BuildContext
@@ -759,6 +758,12 @@ class StateForActualGivenExecution(object):
                 report("".join(traceback.format_exception(type(e), e, tb)))
 
             finally:  # pragma: no cover
+                # Mostly useful for ``find`` and ensuring that objects that
+                # hold on to a reference to ``data`` know that it's now been
+                # finished and they shouldn't attempt to draw more data from
+                # it.
+                ran_example.freeze()
+
                 # This section is in fact entirely covered by the tests in
                 # test_reproduce_failure, but it seems to trigger a lovely set
                 # of coverage bugs: The branches show up as uncovered (despite
@@ -1096,11 +1101,6 @@ def find(
     # type: (...) -> Any
     """Returns the minimal example from the given strategy ``specifier`` that
     matches the predicate function ``condition``."""
-    note_deprecation(
-        "`find(s, f)` is deprecated, because it is rarely used but takes "
-        "ongoing work to maintain as we upgrade other parts of Hypothesis.",
-        since="2019-07-11",
-    )
     if settings is None:
         settings = Settings(max_examples=2000)
     settings = Settings(
